/*
 * 爱组搭，低代码组件化开发平台
 * ------------------------------------------
 * 受知识产权保护，请勿删除版权申明，开发平台不允许做非法网站，后果自负
 */
package com.aizuda.boot.modules.auth.service.impl;

import com.aizuda.boot.modules.auth.param.LoginParam;
import com.aizuda.boot.modules.auth.service.IAuthService;
import com.aizuda.core.api.ApiAssert;
import com.aizuda.boot.modules.system.entity.SysUser;
import com.aizuda.boot.modules.system.service.ISysUserService;
import com.baomidou.kisso.common.encrypt.MD5Salt;
import com.baomidou.kisso.enums.TokenOrigin;
import com.baomidou.kisso.security.token.SSOToken;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.AllArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * 授权 服务实现类
 *
 * @author 青苗
 * @since 2021-12-27
 */
@Service
@AllArgsConstructor
public class AuthServiceImpl implements IAuthService {
    private ISysUserService sysUserService;

    @Override
    public Map<String, Object> login(HttpServletRequest request, HttpServletResponse response, LoginParam loginParam) {
        ApiAssert.fail(StringUtils.isEmpty(loginParam.getUsername())
                || StringUtils.isEmpty(loginParam.getPassword()), "用户名密码不能为空");
        List<SysUser> userList = sysUserService.list(Wrappers.<SysUser>query().eq("username", loginParam.getUsername()));
        ApiAssert.fail(null == userList || userList.size() != 1, "用户不存或异常数据");
        SysUser user = userList.get(0);
        ApiAssert.fail(Objects.equals(0, user.getStatus()), "用户已禁用，请联系管理员");
        ApiAssert.fail(!MD5Salt.isValid(user.getUsername() + user.getSalt()
                , user.getPassword(), loginParam.getPassword()), "登录密码错误");
        // 设置登录 COOKIE
        SSOToken st = new SSOToken();
        st.setId(user.getId());
        st.setIssuer(user.getUsername());
        st.setUserAgent(request);
        st.setOrigin(TokenOrigin.HTML5);
        // 登录信息
        Map<String, Object> loginInfo = new HashMap<>(4);
        loginInfo.put("token", st.getToken());
        loginInfo.put("userInfo", new HashMap<String, Object>(2) {{
            put("userId", user.getId());
            put("userName", user.getNickName());
        }});
        return loginInfo;
    }

}
