package com.aizuda.boot.modules.flw.entity.dto;


import com.aizuda.boot.modules.flw.entity.FlwProcessSetting;
import com.flowlong.bpm.engine.entity.FlwProcess;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang3.StringUtils;

import java.util.List;

/**
 * 流程定义DTO
 *
 * @author 青苗
 * @since 2023-09-07
 */
@Getter
@Setter
public class FlwProcessDTO {

    @Schema(description = "流程定义ID")
    private Long processId;

    @Schema(description = "流程定义名称")
    private String processName;

    @Schema(description = "流程定义说明")
    private String displayName;

    @Schema(description = "流程定义图标")
    private String processIcon;

    @Schema(description = "流程分类ID")
    private Long categoryId;

    @Schema(description = "使用范围 0，全员 1，指定人员（业务关联） 2，均不可提交")
    private Integer useScope;

    @Schema(description = "流程参与者，当使用范围为指定人员时候设置")
    private List<FlwProcessActorDTO> processActorList;

    @Schema(description = "流程定义权限")
    private List<FlwProcessPermissionDTO> processPermissionList;

    @Schema(description = "流程模型定义JSON内容")
    private String modelContent;

    @Schema(description = "流程定义表单")
    private String processForm;

    @Schema(description = "流程定义配置")
    private FlwProcessSetting processSetting;

    public String getProcessName() {
        if (StringUtils.isBlank(processName)) {
            return "未命名审批";
        }
        return this.processName;
    }

    public static FlwProcessDTO of(FlwProcess flwProcess) {
        FlwProcessDTO dto = new FlwProcessDTO();
        dto.setProcessId(flwProcess.getId());
        dto.setProcessName(flwProcess.getProcessName());
        dto.setDisplayName(flwProcess.getDisplayName());
        dto.setProcessIcon(flwProcess.getProcessIcon());
        dto.setUseScope(flwProcess.getUseScope());
        dto.setModelContent(flwProcess.getModelContent());
        return dto;
    }
}
