package com.aizuda.boot.modules.system.service.impl;

import com.aizuda.boot.modules.system.entity.SysMessage;
import com.aizuda.boot.modules.system.entity.vo.InformMessageVO;
import com.aizuda.boot.modules.system.mapper.SysMessageMapper;
import com.aizuda.boot.modules.system.service.ISysMessageService;
import com.aizuda.core.api.ApiAssert;
import com.aizuda.service.service.BaseServiceImpl;
import com.aizuda.service.web.UserSession;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.stereotype.Service;

import java.util.Objects;

/**
 * 系统消息表 服务实现类
 *
 * @author 青苗
 * @since 2023-10-03
 */
@Service
public class SysMessageServiceImpl extends BaseServiceImpl<SysMessageMapper, SysMessage> implements ISysMessageService {

    @Override
    public Page<SysMessage> page(Page<SysMessage> page, SysMessage sysMessage) {
        LambdaQueryWrapper<SysMessage> lqw = Wrappers.lambdaQuery(sysMessage);
        return super.page(page, lqw);
    }

    @Override
    public boolean updateById(SysMessage sysMessage) {
        ApiAssert.fail(null == sysMessage.getId(), "主键不存在无法更新");
        return super.updateById(sysMessage);
    }

    @Override
    public SysMessage getViewedById(Long id) {
        SysMessage sysMessage = this.getById(id);
        if (null != sysMessage && Objects.equals(sysMessage.getViewed(), 0)) {
            UserSession userSession = UserSession.getLoginInfo();
            if (Objects.equals(sysMessage.getUserId(), userSession.getId())) {
                // 接收人查看，更新已读状态
                SysMessage temp = new SysMessage();
                temp.setViewed(1);
                temp.setId(id);
                super.updateById(temp);
            }
        }
        return sysMessage;
    }

    @Override
    public InformMessageVO getInformByUser() {
        UserSession userSession = UserSession.getLoginInfo();
        InformMessageVO vo = new InformMessageVO();
        // 通知
        Page<SysMessage> noticePage = this.pageCategoryByUser(userSession.getId(), 0);
        vo.setNoticeNum(noticePage.getTotal());
        vo.setNoticeList(noticePage.getRecords());
        // 消息
        Page<SysMessage> messagePage = this.pageCategoryByUser(userSession.getId(), 1);
        vo.setMessageNum(messagePage.getTotal());
        vo.setMessageList(messagePage.getRecords());
        // 待办
        Page<SysMessage> todoPage = this.pageCategoryByUser(userSession.getId(), 2);
        vo.setTodoNum(todoPage.getTotal());
        vo.setTodoList(todoPage.getRecords());
        // 总数量
        vo.setTotalNum(vo.getNoticeNum() + vo.getMessageNum() + vo.getTodoNum());
        return vo;
    }

    public Page<SysMessage> pageCategoryByUser(Long userId, Integer category) {
        return super.page(Page.of(1, 5), Wrappers.<SysMessage>lambdaQuery().select(SysMessage::getId, SysMessage::getTitle,
                        SysMessage::getContent, SysMessage::getCreateTime).eq(SysMessage::getCategory, category)
                .eq(SysMessage::getUserId, userId).eq(SysMessage::getViewed, 0).orderByDesc(SysMessage::getCreateTime));
    }

    @Override
    public boolean readAll(UserSession userSession) {
        return lambdaUpdate().set(SysMessage::getViewed, 1).eq(SysMessage::getUserId, userSession.getId()).update();
    }
}
