/*
 * 爱组搭，低代码组件化开发平台
 * ------------------------------------------
 * 受知识产权保护，请勿删除版权申明，开发平台不允许做非法网站，后果自负
 */
package com.aizuda.boot.modules.system.service.impl;

import com.aizuda.boot.modules.system.mapper.SysRoleMapper;
import com.aizuda.boot.modules.system.service.ISysRoleResourceService;
import com.aizuda.boot.modules.system.service.ISysRoleService;
import com.aizuda.boot.modules.system.service.ISysUserRoleService;
import com.aizuda.core.api.ApiAssert;
import com.aizuda.service.service.BaseServiceImpl;
import com.aizuda.boot.modules.system.entity.SysRole;
import com.aizuda.service.vo.TreeVO;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;

/**
 * 系统角色 服务实现类
 *
 * @author 青苗
 * @since 2021-11-03
 */
@Service
@AllArgsConstructor
public class SysRoleServiceImpl extends BaseServiceImpl<SysRoleMapper, SysRole> implements ISysRoleService {
    private ISysUserRoleService sysUserRoleService;
    private ISysRoleResourceService sysRoleResourceService;

    @Override
    public Page<SysRole> page(Page<SysRole> page, SysRole sysRole) {
        LambdaQueryWrapper<SysRole> lqw = Wrappers.lambdaQuery(sysRole);
        return super.page(page, lqw);
    }

    @Override
    public List<TreeVO> listTree() {
        return Optional.ofNullable(super.list(null)).orElse(null).stream()
                .map(t -> new TreeVO(t.getId(), t.getName(), null))
                .collect(Collectors.toList());
    }

    @Override
    public List<SysRole> listAll() {
        return super.list();
    }

    @Override
    public boolean updateById(SysRole sysRole) {
        ApiAssert.isEmpty(sysRole.getId(), "主键不存在无法更新");
        return super.updateById(sysRole);
    }

    @Override
    public boolean removeCheckByIds(List<Long> ids) {
        ids.forEach(id -> {
            ApiAssert.fail(sysUserRoleService.existRelByRoleId(id), "存在角色关联用户不允许删除");
            ApiAssert.fail(sysRoleResourceService.existRelByRoleId(id), "存在角色关联菜单权限不允许删除");
        });
        return super.removeByIds(ids);
    }
}
