package com.aizuda.boot.modules.ws;

import jakarta.websocket.HandshakeResponse;
import jakarta.websocket.server.HandshakeRequest;
import jakarta.websocket.server.ServerEndpointConfig;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.collections.MapUtils;

import java.util.List;
import java.util.Map;

/**
 * WebSocket Endpoint 配置
 *
 * @author 青苗
 * @since 2023-10-03
 */
public class WsEndpointConfigurator extends ServerEndpointConfig.Configurator {

    @Override
    public void modifyHandshake(ServerEndpointConfig config, HandshakeRequest request, HandshakeResponse response) {
        Map<String, List<String>> headers = request.getHeaders();
        if (MapUtils.isNotEmpty(headers)) {
            Map<String, Object> propMap = config.getUserProperties();
            List<String> userAgents = headers.get("User-Agent");
            if (CollectionUtils.isNotEmpty(userAgents)) {
                propMap.put("userAgent", userAgents.get(0));
            }
            List<String> cookieList = headers.get("Cookie");
            if (CollectionUtils.isNotEmpty(cookieList)) {
                String pid = cookieList.get(0);
                if (null != pid && pid.contains("pid=")) {
                    propMap.put("accessToken", pid.split("pid=")[1].split(";")[0]);
                }
            }
        }
    }
}
